==> arrow-instances-free-0.8.1-sources.jar: extension/arrow/free/instances/free/monad/FreeMonadInstance.kt <==
package arrow.free.instances.free.monad

import arrow.Kind
import arrow.core.Either
import arrow.core.Eval
import arrow.core.Tuple2
import arrow.free.ForFree
import arrow.free.Free
import arrow.free.Free.Companion
import arrow.free.instances.FreeMonadInstance
import kotlin.Boolean
import kotlin.Function0
import kotlin.Function1
import kotlin.Suppress
import kotlin.jvm.JvmName

@JvmName("flatMap")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.flatMap(arg1: Function1<A, Kind<Kind<ForFree, S>, B>>): Free<S, B> = arrow.free.Free.monad<S>().run {
  this@flatMap.flatMap<A, B>(arg1) as arrow.free.Free<S, B>
}

@JvmName("tailRecM")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> tailRecM(arg0: A, arg1: Function1<A, Kind<Kind<ForFree, S>, Either<A, B>>>): Free<S, B> = arrow.free.Free
   .monad<S>()
   .tailRecM<A, B>(arg0, arg1) as arrow.free.Free<S, B>

@JvmName("map")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.map(arg1: Function1<A, B>): Free<S, B> = arrow.free.Free.monad<S>().run {
  this@map.map<A, B>(arg1) as arrow.free.Free<S, B>
}

@JvmName("ap")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.ap(arg1: Kind<Kind<ForFree, S>, Function1<A, B>>): Free<S, B> = arrow.free.Free.monad<S>().run {
  this@ap.ap<A, B>(arg1) as arrow.free.Free<S, B>
}

@JvmName("flatten")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A> Kind<Kind<ForFree, S>, Kind<Kind<ForFree, S>, A>>.flatten(): Free<S, A> = arrow.free.Free.monad<S>().run {
  this@flatten.flatten<A>() as arrow.free.Free<S, A>
}

@JvmName("followedBy")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.followedBy(arg1: Kind<Kind<ForFree, S>, B>): Free<S, B> = arrow.free.Free.monad<S>().run {
  this@followedBy.followedBy<A, B>(arg1) as arrow.free.Free<S, B>
}

@JvmName("followedByEval")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.followedByEval(arg1: Eval<Kind<Kind<ForFree, S>, B>>): Free<S, B> = arrow.free.Free.monad<S>().run {
  this@followedByEval.followedByEval<A, B>(arg1) as arrow.free.Free<S, B>
}

@JvmName("effectM")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.effectM(arg1: Function1<A, Kind<Kind<ForFree, S>, B>>): Free<S, A> = arrow.free.Free.monad<S>().run {
  this@effectM.effectM<A, B>(arg1) as arrow.free.Free<S, A>
}

@JvmName("forEffect")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.forEffect(arg1: Kind<Kind<ForFree, S>, B>): Free<S, A> = arrow.free.Free.monad<S>().run {
  this@forEffect.forEffect<A, B>(arg1) as arrow.free.Free<S, A>
}

@JvmName("forEffectEval")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.forEffectEval(arg1: Eval<Kind<Kind<ForFree, S>, B>>): Free<S, A> = arrow.free.Free.monad<S>().run {
  this@forEffectEval.forEffectEval<A, B>(arg1) as arrow.free.Free<S, A>
}

@JvmName("mproduct")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.mproduct(arg1: Function1<A, Kind<Kind<ForFree, S>, B>>): Free<S, Tuple2<A, B>> = arrow.free.Free.monad<S>().run {
  this@mproduct.mproduct<A, B>(arg1) as arrow.free.Free<S, arrow.core.Tuple2<A, B>>
}

@JvmName("ifM")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, B> Kind<Kind<ForFree, S>, Boolean>.ifM(arg1: Function0<Kind<Kind<ForFree, S>, B>>, arg2: Function0<Kind<Kind<ForFree, S>, B>>): Free<S, B> = arrow.free.Free.monad<S>().run {
  this@ifM.ifM<B>(arg1, arg2) as arrow.free.Free<S, B>
}

fun <S> Companion.monad(): FreeMonadInstance<S> = object : arrow.free.instances.FreeMonadInstance<S> {  }

==> arrow-instances-free-0.8.2-sources.jar: extension/arrow/free/instances/free/monad/FreeMonadInstance.kt <==
package arrow.free.instances.free.monad

import arrow.Kind
import arrow.core.Either
import arrow.core.Eval
import arrow.core.Tuple2
import arrow.free.ForFree
import arrow.free.Free
import arrow.free.Free.Companion
import arrow.free.instances.FreeMonadInstance
import arrow.typeclasses.MonadContinuation
import kotlin.Boolean
import kotlin.Function0
import kotlin.Function1
import kotlin.Suppress
import kotlin.jvm.JvmName

@JvmName("flatMap")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.flatMap(arg1: Function1<A, Kind<Kind<ForFree, S>, B>>): Free<S, B> = arrow.free.Free.monad<S>().run {
  this@flatMap.flatMap<A, B>(arg1) as arrow.free.Free<S, B>
}

@JvmName("tailRecM")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> tailRecM(arg0: A, arg1: Function1<A, Kind<Kind<ForFree, S>, Either<A, B>>>): Free<S, B> = arrow.free.Free
   .monad<S>()
   .tailRecM<A, B>(arg0, arg1) as arrow.free.Free<S, B>

@JvmName("map")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.map(arg1: Function1<A, B>): Free<S, B> = arrow.free.Free.monad<S>().run {
  this@map.map<A, B>(arg1) as arrow.free.Free<S, B>
}

@JvmName("ap")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.ap(arg1: Kind<Kind<ForFree, S>, Function1<A, B>>): Free<S, B> = arrow.free.Free.monad<S>().run {
  this@ap.ap<A, B>(arg1) as arrow.free.Free<S, B>
}

@JvmName("flatten")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A> Kind<Kind<ForFree, S>, Kind<Kind<ForFree, S>, A>>.flatten(): Free<S, A> = arrow.free.Free.monad<S>().run {
  this@flatten.flatten<A>() as arrow.free.Free<S, A>
}

@JvmName("followedBy")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.followedBy(arg1: Kind<Kind<ForFree, S>, B>): Free<S, B> = arrow.free.Free.monad<S>().run {
  this@followedBy.followedBy<A, B>(arg1) as arrow.free.Free<S, B>
}

@JvmName("followedByEval")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.followedByEval(arg1: Eval<Kind<Kind<ForFree, S>, B>>): Free<S, B> = arrow.free.Free.monad<S>().run {
  this@followedByEval.followedByEval<A, B>(arg1) as arrow.free.Free<S, B>
}

@JvmName("effectM")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.effectM(arg1: Function1<A, Kind<Kind<ForFree, S>, B>>): Free<S, A> = arrow.free.Free.monad<S>().run {
  this@effectM.effectM<A, B>(arg1) as arrow.free.Free<S, A>
}

@JvmName("forEffect")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.forEffect(arg1: Kind<Kind<ForFree, S>, B>): Free<S, A> = arrow.free.Free.monad<S>().run {
  this@forEffect.forEffect<A, B>(arg1) as arrow.free.Free<S, A>
}

@JvmName("forEffectEval")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.forEffectEval(arg1: Eval<Kind<Kind<ForFree, S>, B>>): Free<S, A> = arrow.free.Free.monad<S>().run {
  this@forEffectEval.forEffectEval<A, B>(arg1) as arrow.free.Free<S, A>
}

@JvmName("mproduct")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.mproduct(arg1: Function1<A, Kind<Kind<ForFree, S>, B>>): Free<S, Tuple2<A, B>> = arrow.free.Free.monad<S>().run {
  this@mproduct.mproduct<A, B>(arg1) as arrow.free.Free<S, arrow.core.Tuple2<A, B>>
}

@JvmName("ifM")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, B> Kind<Kind<ForFree, S>, Boolean>.ifM(arg1: Function0<Kind<Kind<ForFree, S>, B>>, arg2: Function0<Kind<Kind<ForFree, S>, B>>): Free<S, B> = arrow.free.Free.monad<S>().run {
  this@ifM.ifM<B>(arg1, arg2) as arrow.free.Free<S, B>
}

@JvmName("binding")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, B> binding(arg0: suspend MonadContinuation<Kind<ForFree, S>, *>.() -> B): Free<S, B> = arrow.free.Free
   .monad<S>()
   .binding<B>(arg0) as arrow.free.Free<S, B>

fun <S> Companion.monad(): FreeMonadInstance<S> = object : arrow.free.instances.FreeMonadInstance<S> {  }
